instrumenttools.TenorSaxophone
==============================

.. abjad-lineage:: abjad.tools.instrumenttools.TenorSaxophone.TenorSaxophone.TenorSaxophone

.. autoclass:: abjad.tools.instrumenttools.TenorSaxophone.TenorSaxophone.TenorSaxophone
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.instrumenttools.TenorSaxophone.TenorSaxophone.TenorSaxophone.default_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.TenorSaxophone.TenorSaxophone.TenorSaxophone.default_short_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.TenorSaxophone.TenorSaxophone.TenorSaxophone.effective_context
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.TenorSaxophone.TenorSaxophone.TenorSaxophone.interval_of_transposition
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.TenorSaxophone.TenorSaxophone.TenorSaxophone.is_primary_instrument
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.TenorSaxophone.TenorSaxophone.TenorSaxophone.is_secondary_instrument
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.TenorSaxophone.TenorSaxophone.TenorSaxophone.is_transposing
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.TenorSaxophone.TenorSaxophone.TenorSaxophone.lilypond_format
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.TenorSaxophone.TenorSaxophone.TenorSaxophone.start_component
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.TenorSaxophone.TenorSaxophone.TenorSaxophone.storage_format
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.TenorSaxophone.TenorSaxophone.TenorSaxophone.target_context
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.TenorSaxophone.TenorSaxophone.TenorSaxophone.traditional_pitch_range
   :noindex:

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.instrumenttools.TenorSaxophone.TenorSaxophone.TenorSaxophone.all_clefs
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.TenorSaxophone.TenorSaxophone.TenorSaxophone.instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.TenorSaxophone.TenorSaxophone.TenorSaxophone.instrument_name_markup
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.TenorSaxophone.TenorSaxophone.TenorSaxophone.pitch_range
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.TenorSaxophone.TenorSaxophone.TenorSaxophone.primary_clefs
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.TenorSaxophone.TenorSaxophone.TenorSaxophone.short_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.TenorSaxophone.TenorSaxophone.TenorSaxophone.short_instrument_name_markup
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.TenorSaxophone.TenorSaxophone.TenorSaxophone.sounding_pitch_of_fingered_middle_c
   :noindex:

Methods
-------

.. automethod:: abjad.tools.instrumenttools.TenorSaxophone.TenorSaxophone.TenorSaxophone.attach
   :noindex:

.. automethod:: abjad.tools.instrumenttools.TenorSaxophone.TenorSaxophone.TenorSaxophone.detach
   :noindex:

.. automethod:: abjad.tools.instrumenttools.TenorSaxophone.TenorSaxophone.TenorSaxophone.get_default_performer_name
   :noindex:

.. automethod:: abjad.tools.instrumenttools.TenorSaxophone.TenorSaxophone.TenorSaxophone.get_performer_names
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.instrumenttools.TenorSaxophone.TenorSaxophone.TenorSaxophone.__call__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.TenorSaxophone.TenorSaxophone.TenorSaxophone.__delattr__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.TenorSaxophone.TenorSaxophone.TenorSaxophone.__eq__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.TenorSaxophone.TenorSaxophone.TenorSaxophone.__ge__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.TenorSaxophone.TenorSaxophone.TenorSaxophone.__gt__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.TenorSaxophone.TenorSaxophone.TenorSaxophone.__hash__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.TenorSaxophone.TenorSaxophone.TenorSaxophone.__le__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.TenorSaxophone.TenorSaxophone.TenorSaxophone.__lt__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.TenorSaxophone.TenorSaxophone.TenorSaxophone.__ne__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.TenorSaxophone.TenorSaxophone.TenorSaxophone.__repr__
   :noindex:
